@@ -36,21 +36,24 @@ class ImportAnnotations:
             return
 
         options = QFileDialog.Options()
-        file_path, _ = QFileDialog.getOpenFileName(self.annotation_window,
-                                                   "Load Annotations",
-                                                   "",
-                                                   "JSON Files (*.json);;All Files (*)",
-                                                   options=options)
-        if file_path:
+        file_paths, _ = QFileDialog.getOpenFileNames(self.annotation_window,
+                                                     "Load Annotations",
+                                                     "",
+                                                     "JSON Files (*.json);;All Files (*)",
+                                                     options=options)
+        if file_paths:
             try:
                 QApplication.setOverrideCursor(Qt.WaitCursor)
 
-                with open(file_path, 'r') as file:
-                    data = json.load(file)
+                all_data = {}
+                for file_path in file_paths:
+                    with open(file_path, 'r') as file:
+                        data = json.load(file)
+                        all_data.update(data)
 
                 keys = ['label_short_code', 'label_long_code', 'annotation_color', 'image_path', 'label_id']
 
-                filtered_annotations = {p: a for p, a in data.items() if p in self.image_window.image_paths}
+                filtered_annotations = {p: a for p, a in all_data.items() if p in self.image_window.image_paths}
                 total_annotations = sum(len(annotations) for annotations in filtered_annotations.values())
 
                 progress_bar = ProgressBar(self.annotation_window, title="Importing Annotations")
@@ -67,11 +70,12 @@ class ImportAnnotations:
                         short_label = annotation_data['label_short_code']
                         long_label = annotation_data['label_long_code']
                         color = QColor(*annotation_data['annotation_color'])
-
                         label_id = annotation_data['label_id']
-                        self.label_window.add_label_if_not_exists(short_label, long_label, color, label_id)
 
-                        existing_color = self.label_window.get_label_color(short_label, long_label)
+                        # Add the label if it doesn't already exist
+                        self.label_window.add_label_if_not_exists(short_label, long_label, color, label_id)
+                        # Get the color
+                        existing_color = self.label_window.get_label_color(label_id)
 
                         if existing_color != color:
                             annotation_data['annotation_color'] = existing_color.getRgb()
@@ -123,4 +127,4 @@ class ImportAnnotations:
                                     "Error Importing Annotations",
                                     f"An error occurred while importing annotations: {str(e)}")
 
-            QApplication.restoreOverrideCursor()
\ No newline at end of file
+            QApplication.restoreOverrideCursor()
