@@ -94,9 +94,7 @@ class Classify(Base):
             
     def predict(self, inputs=None):
         """
-        Predict the classification results for the given annotations.
-
-        :param inputs: List of annotations (optional)
+        Predict the classification results for the given inputs.
         """
         if self.loaded_model is None:
             return
@@ -110,6 +108,9 @@ class Classify(Base):
         if not inputs:
             # If no annotations are selected, predict all annotations in the image
             inputs = self.annotation_window.get_image_review_annotations()
+        if not inputs:
+            # If no annotations are available, return
+            return
 
         images_np = []
         for annotation in inputs:
@@ -117,12 +118,13 @@ class Classify(Base):
 
         # Predict the classification results
         results = self.loaded_model(images_np,
+                                    conf=self.main_window.get_uncertainty_thresh(),
                                     device=self.main_window.device,
                                     stream=True)
         # Create a result processor
         results_processor = ResultsProcessor(self.main_window,
                                              self.class_mapping,
-                                             uncertainty_thresh=self.get_uncertainty_threshold())
+                                             uncertainty_thresh=self.main_window.get_uncertainty_thresh())
 
         # Process the classification results
         results_processor.process_classification_results(results, inputs)
