@@ -126,9 +126,7 @@ class Detect(Base):
             
     def predict(self, inputs=None):
         """
-        Predict the detection results for the given image paths.
-
-        :param image_paths: List of image paths (optional)
+        Predict the detection results for the given inputs.
         """
         if self.loaded_model is None:
             return
@@ -143,18 +141,18 @@ class Detect(Base):
         # Predict the detection results
         results = self.loaded_model(inputs,
                                     agnostic_nms=True,
-                                    conf=self.get_uncertainty_threshold(),
-                                    iou=self.iou_thresh,
+                                    conf=self.main_window.get_uncertainty_thresh(),
+                                    iou=self.main_window.get_iou_thresh(),
                                     device=self.main_window.device,
                                     stream=True)
 
         # Create a result processor
         results_processor = ResultsProcessor(self.main_window,
                                              self.class_mapping,
-                                             uncertainty_thresh=self.get_uncertainty_threshold(),
-                                             iou_thresh=self.iou_thresh,
-                                             min_area_thresh=self.area_thresh_min,
-                                             max_area_thresh=self.area_thresh_max)
+                                             uncertainty_thresh=self.main_window.get_uncertainty_thresh(),
+                                             iou_thresh=self.main_window.get_iou_thresh(),
+                                             min_area_thresh=self.main_window.get_area_thresh_min(),
+                                             max_area_thresh=self.main_window.get_area_thresh_max())
         
         # Check if SAM model is deployed
         if self.use_sam_dropdown.currentText() == "True":
