@@ -17,7 +17,7 @@ from coralnet_toolbox.Annotations import (
 
 from coralnet_toolbox.Tools import (
     PanTool,
-    PatchTool, 
+    PatchTool,
     PolygonTool,
     RectangleTool,
     SAMTool,
@@ -42,6 +42,7 @@ class AnnotationWindow(QGraphicsView):
     annotationSizeChanged = pyqtSignal(int)  # Signal to emit when annotation size changes
     annotationSelected = pyqtSignal(int)  # Signal to emit when annotation is selected
     annotationDeleted = pyqtSignal(str)  # Signal to emit when annotation is deleted
+    annotationCreated = pyqtSignal(str)  # Signal to emit when annotation is created
     hover_point = pyqtSignal(QPointF)  # Signal to emit when mouse hovers over a point
 
     def __init__(self, main_window, parent=None):
@@ -54,7 +55,7 @@ class AnnotationWindow(QGraphicsView):
         self.annotation_size = 224
         self.annotation_color = None
         self.transparency = 128
-        
+
         self.zoom_factor = 1.0
         self.pan_active = False
         self.pan_start = None
@@ -136,11 +137,12 @@ class AnnotationWindow(QGraphicsView):
         if self.active_image and self.selected_tool:
             self.tools[self.selected_tool].keyPressEvent(event)
         super().keyPressEvent(event)
-        
-        # Handle the hot key for deleting 
-        if event.modifiers() & Qt.ControlModifier and event.key() == Qt.Key_Delete:
-            if self.selected_annotations:
-                self.delete_selected_annotation()
+
+        # Handle the hot key for deleting (backspace or delete) selected annotations
+        if event.modifiers() & Qt.ControlModifier:
+            if event.key() == Qt.Key_Delete or event.key() == Qt.Key_Backspace:
+                if self.selected_annotations:
+                    self.delete_selected_annotation()
 
     def keyReleaseEvent(self, event):
         if self.active_image and self.selected_tool:
@@ -156,7 +158,7 @@ class AnnotationWindow(QGraphicsView):
             pos = self.mapToScene(pos)
 
         return image_rect.contains(pos)
-    
+
     def cursorInViewport(self, pos):
         if not pos:
             return False
@@ -226,14 +228,14 @@ class AnnotationWindow(QGraphicsView):
         if len(self.selected_annotations) <= 1:
             # Emit that the annotation size has changed
             self.annotationSizeChanged.emit(self.annotation_size)
-            
+
     def is_annotation_moveable(self, annotation):
         if annotation.show_message:
             self.unselect_annotations()
             annotation.show_warning_message()
             return False
         return True
-        
+
     def toggle_cursor_annotation(self, scene_pos: QPointF = None):
 
         if self.cursor_annotation:
@@ -283,7 +285,7 @@ class AnnotationWindow(QGraphicsView):
         self.scene.addItem(QGraphicsPixmapItem(self.image_pixmap))
         self.fitInView(self.scene.sceneRect(), Qt.KeepAspectRatio)
         self.tools["zoom"].calculate_min_zoom()
-        
+
         self.toggle_cursor_annotation()
 
         # Set the image dimensions, and current view in status bar
@@ -323,18 +325,52 @@ class AnnotationWindow(QGraphicsView):
         self.centerOn(annotation_center)
 
     def cycle_annotations(self, direction):
+        # Get the annotations for the current image
+        annotations = self.get_image_annotations()
+        if not annotations:
+            return
+
         if self.selected_tool == "select" and self.active_image:
-            annotations = self.get_image_annotations()
-            if annotations:
+
+            if self.main_window.label_window.label_locked:
+                locked_label = self.main_window.label_window.locked_label
+                indices = [i for i, a in enumerate(annotations) if a.label.id == locked_label.id]
+
+                if not indices:
+                    return
+
                 if self.selected_annotations:
                     current_index = annotations.index(self.selected_annotations[0])
-                    new_index = (current_index + direction) % len(annotations)
                 else:
-                    new_index = 0
-                # Select the new annotation
-                self.select_annotation(annotations[new_index])
-                # Center the view on the new annotation
-                self.center_on_annotation(annotations[new_index])
+                    current_index = indices[0]
+
+                if current_index in indices:
+                    # Find position in indices list and cycle within that
+                    current_pos = indices.index(current_index)
+                    new_pos = (current_pos + direction) % len(indices)
+                    new_index = indices[new_pos]  # Get the actual annotation index
+                else:
+                    # Find next valid index based on direction
+                    if direction > 0:
+                        next_indices = [i for i in indices if i > current_index]
+                        new_index = next_indices[0] if next_indices else indices[0]
+                    else:
+                        prev_indices = [i for i in indices if i < current_index]
+                        new_index = prev_indices[-1] if prev_indices else indices[-1]
+
+            elif self.selected_annotations:
+                # Cycle through all the annotations
+                current_index = annotations.index(self.selected_annotations[0])
+                new_index = (current_index + direction) % len(annotations)
+
+            else:
+                # Select the first annotation
+                new_index = 0
+
+            # Select the new annotation
+            self.select_annotation(annotations[new_index])
+            # Center the view on the new annotation
+            self.center_on_annotation(annotations[new_index])
 
     def select_annotation(self, annotation, ctrl_pressed=False):
         if not ctrl_pressed:
@@ -372,6 +408,17 @@ class AnnotationWindow(QGraphicsView):
         if len(self.selected_annotations) > 1:
             self.main_window.label_window.deselect_active_label()
             self.main_window.confidence_window.clear_display()
+            
+    # TODO test
+    def select_annotations(self):
+        """Select all annotations in the current image."""
+        annotations = self.get_image_annotations()
+        for annotation in annotations:
+            if self.main_window.label_window.label_locked:
+                if annotation.label.id == self.main_window.label_window.locked_label.id:
+                    self.select_annotation(annotation, ctrl_pressed=True)
+            else:       
+                self.select_annotation(annotation, ctrl_pressed=True)
 
     def unselect_annotation(self, annotation):
         if annotation in self.selected_annotations:
@@ -401,7 +448,7 @@ class AnnotationWindow(QGraphicsView):
         # Initialize the progress bar
         progress_bar = ProgressBar(self, title="Loading Annotations")
         progress_bar.show()
-        
+
         # Crop all the annotations for current image (if not already cropped)
         annotations = self.crop_image_annotations(return_annotations=True)
         progress_bar.start_progress(len(annotations))
@@ -418,12 +465,12 @@ class AnnotationWindow(QGraphicsView):
 
         QApplication.processEvents()
         self.viewport().update()
-        
+
     def load_these_annotations(self, image_path, annotations):
         # Initialize the progress bar
         progress_bar = ProgressBar(self, title="Loading Annotations")
         progress_bar.show()
-        
+
         # Crop all the annotations for current image (if not already cropped)
         annotations = self.crop_these_image_annotations(image_path, annotations)
         progress_bar.start_progress(len(annotations))
@@ -486,7 +533,7 @@ class AnnotationWindow(QGraphicsView):
         progress_bar = ProgressBar(self, title="Cropping Annotations")
         progress_bar.show()
         progress_bar.start_progress(len(annotations))
-        
+
         # Get the rasterio representation
         rasterio_image = self.main_window.image_window.rasterio_open(image_path)
         # Loop through the annotations, crop the image if not already cropped
@@ -494,7 +541,7 @@ class AnnotationWindow(QGraphicsView):
             if not annotation.cropped_image:
                 annotation.create_cropped_image(rasterio_image)
             progress_bar.update_progress()
-            
+
         progress_bar.stop_progress()
         progress_bar.close()
 
@@ -503,13 +550,13 @@ class AnnotationWindow(QGraphicsView):
         progress_bar = ProgressBar(self, title="Cropping Annotations")
         progress_bar.show()
         progress_bar.start_progress(len(annotations))
-        
+
         # Create a lock for thread-safe access to the rasterio dataset
         lock = threading.Lock()
-        
+
         # Get the rasterio representation
         rasterio_image = self.main_window.image_window.rasterio_open(image_path)
-        
+
         def crop_annotation(annotation):
             with lock:
                 if not annotation.cropped_image:
@@ -522,13 +569,15 @@ class AnnotationWindow(QGraphicsView):
             for future in as_completed(futures):
                 future.result()  # Ensure any exceptions are raised
                 progress_bar.update_progress()
-        
+
         progress_bar.stop_progress()
         progress_bar.close()
 
     def add_annotation(self, scene_pos: QPointF = None):
         if not self.selected_label:
-            QMessageBox.warning(self, "No Label Selected", "A label must be selected before adding an annotation.")
+            QMessageBox.warning(self,
+                                "No Label Selected",
+                                "A label must be selected before adding an annotation.")
             return
 
         # Return if the isn't an active image
@@ -556,16 +605,17 @@ class AnnotationWindow(QGraphicsView):
         annotation.annotationUpdated.connect(self.main_window.confidence_window.display_cropped_image)
 
         self.annotations_dict[annotation.id] = annotation
-
         self.main_window.confidence_window.display_cropped_image(annotation)
+        self.annotationCreated.emit(annotation.id)
 
     def delete_annotation(self, annotation_id):
         if annotation_id in self.annotations_dict:
-            # Get the annotation from dict, delete it
+            # Get the annotation from dict
             annotation = self.annotations_dict[annotation_id]
+            # Delete the annotation
             annotation.delete()
-            self.annotationDeleted.emit(annotation.id)
             del self.annotations_dict[annotation_id]
+            self.annotationDeleted.emit(annotation_id)
             # Clear the confidence window
             self.main_window.confidence_window.clear_display()
 
@@ -611,4 +661,4 @@ class AnnotationWindow(QGraphicsView):
                     del item
             self.scene.deleteLater()
         self.scene = QGraphicsScene(self)
-        self.setScene(self.scene)
\ No newline at end of file
+        self.setScene(self.scene)
