@@ -1,15 +1,17 @@
-import json
 import random
 import uuid
 import warnings
 
 from PyQt5.QtCore import Qt, pyqtSignal, QMimeData
 from PyQt5.QtGui import QColor, QPainter, QPen, QBrush, QFontMetrics, QDrag
-from PyQt5.QtWidgets import (QFileDialog, QGridLayout, QScrollArea, QMessageBox, QCheckBox, QWidget, QVBoxLayout,
-                             QColorDialog, QLineEdit, QDialog, QHBoxLayout, QPushButton, QApplication, QSizePolicy)
+from PyQt5.QtWidgets import (QGridLayout, QScrollArea, QMessageBox, QCheckBox, QWidget,
+                             QVBoxLayout, QColorDialog, QLineEdit, QDialog, QHBoxLayout,
+                             QPushButton, QApplication, QGroupBox)
 
 warnings.filterwarnings("ignore", category=DeprecationWarning)
 
+from coralnet_toolbox.Icons import get_icon
+
 
 # ----------------------------------------------------------------------------------------------------------------------
 # Classes
@@ -152,14 +154,17 @@ class Label(QWidget):
 
 
 class LabelWindow(QWidget):
-    labelSelected = pyqtSignal(object)  # Signal to emit the entire Label object
-    transparencyChanged = pyqtSignal(int)  # Signal to emit the transparency value
+    labelSelected = pyqtSignal(object)
+    transparencyChanged = pyqtSignal(int)
 
     def __init__(self, main_window):
         super().__init__()
         self.main_window = main_window
         self.annotation_window = main_window.annotation_window
 
+        self.label_locked = False
+        self.locked_label = None
+
         self.label_height = 30
         self.label_width = 100
         self.labels_per_row = 1  # Initial value, will be updated
@@ -168,25 +173,44 @@ class LabelWindow(QWidget):
         self.main_layout.setContentsMargins(0, 0, 0, 0)
         self.main_layout.setSpacing(0)
 
+        # Create a groupbox and set its title and style sheet
+        self.groupBox = QGroupBox("Label Window")
+
+        self.groupBoxLayout = QVBoxLayout()
+        self.groupBox.setLayout(self.groupBoxLayout)
+
         # Top bar with Add Label, Edit Label, and Delete Label buttons
         self.top_bar = QHBoxLayout()
-        self.add_label_button = QPushButton("Add Label")
+        self.add_label_button = QPushButton()
+        self.add_label_button.setIcon(self.main_window.add_icon)
+        self.add_label_button.setToolTip("Add Label")
         self.add_label_button.setFixedSize(self.label_width, self.label_height)
         self.top_bar.addWidget(self.add_label_button)
 
-        self.edit_label_button = QPushButton("Edit Label")
-        self.edit_label_button.setFixedSize(self.label_width, self.label_height)
-        self.edit_label_button.setEnabled(False)  # Initially disabled
-        self.top_bar.addWidget(self.edit_label_button)
-
-        self.delete_label_button = QPushButton("Delete Label")
+        self.delete_label_button = QPushButton()
+        self.delete_label_button.setIcon(self.main_window.remove_icon)
+        self.delete_label_button.setToolTip("Delete Label")
         self.delete_label_button.setFixedSize(self.label_width, self.label_height)
         self.delete_label_button.setEnabled(False)  # Initially disabled
         self.top_bar.addWidget(self.delete_label_button)
 
+        self.edit_label_button = QPushButton()
+        self.edit_label_button.setIcon(self.main_window.edit_icon)
+        self.edit_label_button.setToolTip("Edit Label")
+        self.edit_label_button.setFixedSize(self.label_width, self.label_height)
+        self.edit_label_button.setEnabled(False)  # Initially disabled
+        self.top_bar.addWidget(self.edit_label_button)
+
         self.top_bar.addStretch()  # Add stretch to the right side
 
-        self.main_layout.addLayout(self.top_bar)
+        # Lock button
+        self.label_lock_button = QPushButton()
+        self.label_lock_button.setIcon(self.main_window.unlock_icon)
+        self.label_lock_button.setToolTip("Label Unlocked")
+        self.label_lock_button.setCheckable(True)
+        self.label_lock_button.toggled.connect(self.toggle_label_lock)
+        self.label_lock_button.setFixedSize(self.label_height, self.label_height)
+        self.top_bar.addWidget(self.label_lock_button)
 
         # Scroll area for labels
         self.scroll_area = QScrollArea()
@@ -197,11 +221,20 @@ class LabelWindow(QWidget):
         self.grid_layout.setSpacing(0)
         self.grid_layout.setContentsMargins(0, 0, 0, 0)
         self.scroll_area.setWidget(self.scroll_content)
-        self.main_layout.addWidget(self.scroll_area)
 
+        # Add layouts to the groupbox layout
+        self.groupBoxLayout.addLayout(self.top_bar)
+        self.groupBoxLayout.addWidget(self.scroll_area)
+
+        # Add the groupbox to the main layout
+        self.main_layout.addWidget(self.groupBox)
+
+        # Connections
         self.add_label_button.clicked.connect(self.open_add_label_dialog)
         self.edit_label_button.clicked.connect(self.open_edit_label_dialog)
         self.delete_label_button.clicked.connect(self.delete_active_label)
+
+        # Initialize labels
         self.labels = []
         self.active_label = None
 
@@ -279,26 +312,33 @@ class LabelWindow(QWidget):
         self.update_labels_per_row()
         self.reorganize_labels()
         self.set_active_label(label)
+        # Update search bars
+        self.main_window.image_window.update_search_bars()
         QApplication.processEvents()
 
         return label
 
     def set_active_label(self, selected_label):
+
         if self.active_label and self.active_label != selected_label:
+            # Deselect the active label
             self.deselect_active_label()
 
+        # Make the selected label active
         self.active_label = selected_label
         self.active_label.select()
         self.labelSelected.emit(selected_label)
+
+        # Update the transparency slider with the new label's transparency
         self.transparencyChanged.emit(self.active_label.transparency)
 
-        # Enable or disable the Edit Label and Delete Label buttons based on whether a label is selected
-        self.edit_label_button.setEnabled(self.active_label is not None)
-        self.delete_label_button.setEnabled(self.active_label is not None)
+        # Only enable edit/delete buttons if not locked
+        if not self.label_locked:
+            self.delete_label_button.setEnabled(self.active_label is not None)
+            self.edit_label_button.setEnabled(self.active_label is not None)
 
         # Update annotations with the new label
         self.update_annotations_with_label(selected_label)
-        # self.adjust_scrollbar_for_active_label()
         self.scroll_area.ensureWidgetVisible(self.active_label)
 
     def set_label_transparency(self, transparency):
@@ -309,7 +349,6 @@ class LabelWindow(QWidget):
             # Update the active label's transparency
             self.active_label.update_transparency(transparency)
             # Update the transparency of all annotations with the active label
-            scene = self.annotation_window.scene
             for annotation in self.annotation_window.annotations_dict.values():
                 if annotation.label.id == self.active_label.id:
                     annotation.update_transparency(transparency)
@@ -337,14 +376,25 @@ class LabelWindow(QWidget):
     def update_annotations_with_label(self, label):
         for annotation in self.annotation_window.annotations_dict.values():
             if annotation.label.id == label.id:
+                # Update the annotation label
                 annotation.update_label(label)
+                # Get the transparency of the label
+                transparency = self.get_label_transparency(label.id)
+                # Update the annotation transparency
+                annotation.update_transparency(transparency)
 
-    def get_label_color(self, short_label_code, long_label_code):
+    def get_label_color(self, label_id):
         for label in self.labels:
-            if short_label_code == label.short_label_code and long_label_code == label.long_label_code:
+            if label.id == label_id:
                 return label.color
         return None
 
+    def get_label_transparency(self, label_id):
+        for label in self.labels:
+            if label.id == label_id:
+                return label.transparency
+        return None
+
     def get_label_by_id(self, label_id):
         for label in self.labels:
             if label.id == label_id:
@@ -407,6 +457,9 @@ class LabelWindow(QWidget):
         self.update_labels_per_row()
         self.reorganize_labels()
 
+        # Refresh the scene with the new label
+        self.annotation_window.set_image(self.annotation_window.current_image_path)
+
     def delete_label(self, label):
         if (label.short_label_code == "Review" and
                 label.long_label_code == "Review" and
@@ -451,7 +504,7 @@ class LabelWindow(QWidget):
         self.reorganize_labels()
 
     def handle_wasd_key(self, key):
-        if not self.active_label:
+        if not self.active_label or self.label_locked:
             return
 
         try:
@@ -475,12 +528,46 @@ class LabelWindow(QWidget):
         if 0 <= new_index < len(self.labels):
             self.set_active_label(self.labels[new_index])
 
+    def toggle_label_lock(self, checked):
+        """Toggle between lock and unlock states"""
+        # Check if select tool is active, if not, revert the button state and return
+        if self.main_window.annotation_window.selected_tool != "select":
+            self.label_lock_button.setChecked(False)  # Revert the toggle
+            return
+
+        if checked:
+            self.label_lock_button.setIcon(self.main_window.lock_icon)
+            self.label_lock_button.setToolTip("Label Locked")  # Changed
+            # Set add, edit, and delete label to disabled
+            self.add_label_button.setEnabled(False)
+            self.delete_label_button.setEnabled(False)
+            self.edit_label_button.setEnabled(False)
+            # Set the active label to locked
+            self.locked_label = self.active_label
+        else:
+            self.label_lock_button.setIcon(self.main_window.unlock_icon)
+            self.label_lock_button.setToolTip("Label Unlocked")  # Changed
+            # Set add, edit, and delete label to enabled
+            self.add_label_button.setEnabled(True)
+            self.delete_label_button.setEnabled(True)
+            self.edit_label_button.setEnabled(True)
+            # Reset the locked label
+            self.locked_label = None
+
+        # Set the label_locked attribute
+        self.label_locked = checked
+
+    def unlock_label_lock(self):
+        # Triggers the signal to toggle_label_lock method
+        self.label_lock_button.setChecked(False)
+
 
 class AddLabelDialog(QDialog):
     def __init__(self, label_window, parent=None):
         super().__init__(parent)
         self.label_window = label_window
 
+        self.setWindowIcon(get_icon("coral.png"))
         self.setWindowTitle("Add Label")
         self.setObjectName("AddLabelDialog")
 
@@ -549,7 +636,9 @@ class EditLabelDialog(QDialog):
         self.label_window = label_window
         self.label = label
 
+        self.setWindowIcon(get_icon("coral.png"))
         self.setWindowTitle("Edit Label")
+        self.setObjectName("EditLabelDialog")
 
         self.layout = QVBoxLayout(self)
 
@@ -632,4 +721,4 @@ class EditLabelDialog(QDialog):
             self.label.update_label_color(self.color)
             self.accept()
 
-            self.label_window.edit_labels(self.label, self.label, delete_old=False)
\ No newline at end of file
+            self.label_window.edit_labels(self.label, self.label, delete_old=False)
