@@ -59,6 +59,7 @@ class DeployGeneratorDialog(QDialog):
         self.area_thresh_max = 0.40
 
         self.task = 'detect'
+        self.max_detect = 300
         self.loaded_model = None
         self.model_path = None
         self.class_mapping = {0: 'Review'}
@@ -192,6 +193,13 @@ class DeployGeneratorDialog(QDialog):
         layout.addRow("Area Threshold", self.area_threshold_slider)
         layout.addRow("", self.area_threshold_label)
         
+        # Max detections spinbox
+        self.max_detections_spinbox = QSpinBox()
+        self.max_detections_spinbox.setRange(1, 10000)
+        self.max_detections_spinbox.setValue(self.max_detect)
+        label = QLabel("Max Detections")
+        layout.addRow(label, self.max_detections_spinbox)
+                
         # Task dropdown
         self.use_task_dropdown = QComboBox()
         self.use_task_dropdown.addItems(["Detect", "Segment"])
@@ -297,7 +305,7 @@ class DeployGeneratorDialog(QDialog):
         self.area_thresh_min = min_val / 100.0
         self.area_thresh_max = max_val / 100.0
         self.main_window.update_area_thresh(self.area_thresh_min, self.area_thresh_max)
-        self.area_threshold_label.setText(f"{self.area_thresh_min:.2f} - {self.area_thresh_max:.2f}")     
+        self.area_threshold_label.setText(f"{self.area_thresh_min:.2f} - {self.area_thresh_max:.2f}")  
 
     def load_model(self):
         """
@@ -311,6 +319,7 @@ class DeployGeneratorDialog(QDialog):
         try:
             # Get selected model path
             self.model_path = self.models[self.model_combo.currentText()]
+            self.max_detect = self.max_detections_spinbox.value()
             self.task = self.use_task_dropdown.currentText().lower()
 
             # Set the parameters
@@ -318,11 +327,12 @@ class DeployGeneratorDialog(QDialog):
                              task=self.task, 
                              mode='predict', 
                              save=False, 
-                             max_det=1000,
+                             max_det=self.max_detect,
                              imgsz=self.get_imgsz(),
-                             conf=self.get_uncertainty_threshold(), 
-                             iou=self.iou_thresh, 
+                             conf=0.00, 
+                             iou=1.00, 
                              device=self.main_window.device)
+            
             # Load the model
             self.loaded_model = FastSAMPredictor(overrides=overrides)
             
@@ -349,18 +359,6 @@ class DeployGeneratorDialog(QDialog):
         self.imgsz = self.imgsz_spinbox.value()
         return self.imgsz
 
-    def get_uncertainty_threshold(self):
-        """
-        Get the uncertainty threshold, limiting it to a maximum of 0.10.
-
-        Returns:
-            Adjusted uncertainty threshold value.
-        """
-        if self.main_window.get_uncertainty_thresh() < 0.10:
-            return self.main_window.get_uncertainty_thresh()
-        else:
-            return 0.10  # Arbitrary value to prevent too many detections
-
     def predict(self, image_paths=None):
         """
         Make predictions on the given image paths using the loaded model.
@@ -369,7 +367,6 @@ class DeployGeneratorDialog(QDialog):
             image_paths: List of image paths to process. If None, uses the current image.
         """
         if not self.loaded_model:
-            QMessageBox.critical(self, "Error", "No model loaded")
             return
    
         if not image_paths:
@@ -398,19 +395,19 @@ class DeployGeneratorDialog(QDialog):
             if self.use_sam_dropdown.currentText() == "True":
                 # Apply SAM to the detection results
                 results = self.sam_dialog.predict_from_results(results, self.class_mapping)
-            
-            # Create a results processor
-            results_processor = ResultsProcessor(self.main_window, 
-                                                 self.class_mapping,
-                                                 uncertainty_thresh=self.get_uncertainty_threshold(),
-                                                 iou_thresh=self.iou_thresh,
-                                                 min_area_thresh=self.area_thresh_min,
-                                                 max_area_thresh=self.area_thresh_max)
                         
             # Update the progress bar
             progress_bar.update_progress()
             
-            if self.task == 'segment' or self.use_sam_dropdown.currentText() == "True":
+            # Create a results processor
+            results_processor = ResultsProcessor(self.main_window, 
+                                                 self.class_mapping,
+                                                 uncertainty_thresh=self.main_window.get_uncertainty_thresh(),
+                                                 iou_thresh=self.main_window.get_iou_thresh(),
+                                                 min_area_thresh=self.main_window.get_area_thresh_min(),
+                                                 max_area_thresh=self.main_window.get_area_thresh_max())
+            
+            if self.task.lower() == 'segment' or self.use_sam_dropdown.currentText() == "True":
                 results_processor.process_segmentation_results(results)
             else:
                 results_processor.process_detection_results(results)
