@@ -2,7 +2,7 @@
 
 from coralnet_toolbox.main import run
 
-__version__ = "0.0.1"
+__version__ = "0.0.21"
 __author__ = "Jordan Pierce"
 __email__ = "jordan.pierce@noaa.gov"
-__credits__ = "National Center for Coastal and Ocean Sciences"
\ No newline at end of file
+__credits__ = "National Center for Coastal and Ocean Sciences (NCCOS)"
\ No newline at end of file
